@@ -539,29 +539,30 @@ class DefinitionJsonDeserializer:
 
 	def _deserialize_version(self, obj):
 		result = {}
-		mutations = []
-		for mutation in obj['mutations']:
-			action = mutation['action']
-			action = VersionMutationType[action]
-			description = None
-			if 'description' in mutation:
-				description = mutation['description']
-			config = mutation['config']
-			supported_mutations = {
-					VersionMutationType.AddField,
-					VersionMutationType.RemoveField,
-					VersionMutationType.MutateField,
-					VersionMutationType.RenameField
-				}
-			if action not in supported_mutations:
-				raise Exception('Version Mutation Not Implemented: {0}'.format(action))
-			mutations.append(Utils.VersionMutation(action, config, description))
-			if 'definition_name' in config:
-				definition_name = config['definition_name']
-				if not Index.exists(definition_name):
-					dependent_definition_profile = self.deserialize(definition_name)
-					Index.register_definition(**dependent_definition_profile)
-		result['mutations'] = mutations
+		if 'mutations' in obj:
+			mutations = []
+			for mutation in obj['mutations']:
+				action = mutation['action']
+				action = VersionMutationType[action]
+				description = None
+				if 'description' in mutation:
+					description = mutation['description']
+				config = mutation['config']
+				supported_mutations = {
+						VersionMutationType.AddField,
+						VersionMutationType.RemoveField,
+						VersionMutationType.MutateField,
+						VersionMutationType.RenameField
+					}
+				if action not in supported_mutations:
+					raise Exception('Version Mutation Not Implemented: {0}'.format(action))
+				mutations.append(Utils.VersionMutation(action, config, description))
+				if 'definition_name' in config:
+					definition_name = config['definition_name']
+					if not Index.exists(definition_name):
+						dependent_definition_profile = self.deserialize(definition_name)
+						Index.register_definition(**dependent_definition_profile)
+			result['mutations'] = mutations
 		if 'conversion' in obj:
 			config = obj['conversion']['config']
 			type_fqn = obj['conversion']['type']
@@ -942,22 +943,30 @@ class Index:
 				result[field_name] = field
 		return result
 
-	def _extend_model(schema, mutations, version):
-		model = {}
-		inherited_mutations = list(mutations)
+	def _get_inherited_fields(schema, version):
+		result = {}
 		for inherited_definition_name in schema.inherits:
 			parent_definition = Index.get(inherited_definition_name, version)
 			inherited_fields = parent_definition.list_fields()
 			for field_name in inherited_fields:
-				model[field_name] = inherited_fields[field_name]
-			parent_mutations = parent_definition.get_mutations()
-			inherited_mutations.extend(parent_mutations)
-			Index._execute_field_init(model, parent_definition.get_data_format().field_init_actions)
+				result[field_name] = inherited_fields[field_name]
+		return result
+
+	def _get_inherited_mutations(schema, version):
+		result = []
+		inherited_mutations = []
+		for inherited_definition_name in schema.inherits:
+			parent_definition = Index.get(inherited_definition_name, version)
+			result.extend(parent_definition.get_mutations())
+		return result
+
+	def _extend_model(schema, cumulative_mutations, version):
+		model = Index._get_inherited_fields(schema, version)
 		for k in schema.model:
 			model[k] = schema.model[k]
-		model = Index._mutate_model(model, mutations)
+		model = Index._mutate_model(model, cumulative_mutations)
 		model = Index._execute_field_init(model, schema.field_init_actions)
-		return model, inherited_mutations
+		return model
 
 	def register_definition(
 				name,
@@ -983,6 +992,7 @@ class Index:
 		latest_def_version = None
 		if Utils.Empty.isempty(versions) is True:
 			versions = {}
+		cumulative_mutations = []
 		mutated_data_format = data_format
 		initial_version_index = Index._versions_idx[base_version]
 		for version in Index._versions[initial_version_index:]:
@@ -996,9 +1006,13 @@ class Index:
 					mutations = versions[version]['mutations']
 				if 'conversion' in versions[version]:
 					version_conversion = versions[version]['conversion']
+			cumulative_mutations.extend(mutations)
 			if data_type == DataType.Object:
-				mutated_data_format = mutated_data_format.copy()
-				mutated_data_format.model, mutations = Index._extend_model(mutated_data_format, mutations, version)
+				mutated_data_format = data_format.copy()
+				mutated_data_format.model = Index._extend_model(mutated_data_format, cumulative_mutations, version)
+				inherited_mutations = Index._get_inherited_mutations(mutated_data_format, version)
+				inherited_mutations.extend(mutations)
+				mutations = inherited_mutations
 			mutated_definition = Definition(
 					name=name,
 					aliases=aliases,
@@ -1139,8 +1153,6 @@ class Index:
 				next_version = Index._versions[i]
 				next_definition = Index.get(definition_or_name, next_version)
 				i = i + 1
-				if last_version == next_definition.get_version():
-					continue
 				last_version = next_definition.get_version()
 				conversion = next_definition.get_version_conversion()
 				if conversion is None:
