@@ -34,10 +34,20 @@ class Schema:
 			if Utils.Empty.isempty(value):
 				return
 			setattr(self, name, value)
-		if isinstance(model, type):
-			model = model()
+		obj = None
+		if isinstance(model, dict) is not True:
+			obj = model
+		if isinstance(obj, type):
+			if Utils.Empty.isempty(model_name) is True:
+				model_name = model.__class__.__name__
+			obj = model()
+			model = {}
+			for k in dir(obj):
+				v = getattr(obj, k)
+				if isinstance(v, Field) is True:
+					model[k] = v
 		elif isinstance(model, str):
-			model = Definitions.Index.get(model).data_format.model
+			model = Definitions.Index.get(model, version).data_format.model
 		_set_member('model', model)
 		_set_member('model_name', model_name)
 		_set_member('allow_unknown_fields', allow_unknown_fields)
@@ -48,8 +58,6 @@ class Schema:
 		_set_member('return_unknown_fields', return_unknown_fields)
 		_set_member('inherits', inherits)
 		_set_member('field_init_actions', field_init_actions)
-		if self.model_name is None:
-			self.model_name = model.__class__.__name__
 
 	def copy(self):
 		model_copy = {}
