@@ -48,3 +48,13 @@ class VersionMutation:
 		self.action = action
 		self.config = config
 		self.description = description
+
+	def __str__(self):
+		return '<VersionMutation action={0}, desc={1}, config={2}>'.format(
+				self.action,
+				self.description,
+				self.config
+			)
+
+	def __repr__(self):
+		return self.__str__()
