@@ -17,6 +17,13 @@ class VersionMutationType(Enum):
 	AddField = 1 # name + def
 	RemoveField = 2 # name
 	MutateField = 3 # new def (no rename)
-	AddRule = 4 # index
-	RemoveRule = 5 # rule index
-	MutateRule = 6 # rule index + new rule + config
+	RenameField = 4
+	AddRule = 5 # index
+	RemoveRule = 6 # rule index
+	MutateRule = 7 # rule index + new rule + config
+
+
+@unique
+class ValidationMode(Enum):
+	Input = 1
+	Output = 2
\ No newline at end of file
