@@ -38,37 +38,64 @@ class Boolean(Rules.Rule):
 			)
 
 
-class TestModel:
-	a = None
-	b = Schemas.Field(input_name='b', required=False)
+json_str = '''
+{
+	"a": {
+		"data_type": "Boolean",
+		"default_value": false,
+		"default_value_type": "builtins.bool",
+		"description": "Demo field a.",
+		"rules": [
+			{
+				"config": {},
+				"type": "test.test_example_complex_array_generator.Boolean"
+			}
+		]
+	},
+	"b": {
+		"data_type": "Boolean",
+		"default_value": false,
+		"default_value_type": "builtins.bool",
+		"description": "Demo field b.",
+		"rules": [
+			{
+				"config": {},
+				"type": "test.test_example_complex_array_generator.Boolean"
+			}
+		]
+	},
+	"TestModel": {
+		"data_format": {
+			"load_defaults": true,
+			"model": {
+				"a": {
+					"required": true
+				},
+				"b": {
+					"required": false
+				}
+			},
+			"model_type": "SchemaDefinition"
+		},
+		"data_format_type": "cro_validate.classes.schema_classes.Schema",
+		"data_type": "Object",
+		"description": "Root model."
+	},
+	"TestModelArray": {
+		"data_format": "TestModel",
+		"data_format_type": "builtins.str",
+		"data_type": "Array",
+		"description": "TestModel array."
+	}
+}
+'''
 
 
 def register():
 	DefinitionApi.clear()
 
-	DefinitionApi.register_definition(
-			name='a',
-			data_type=DataType.Boolean,
-			default_value=False,
-			rules=[Boolean()]
-		)
-
-	DefinitionApi.register_definition(
-			name='b',
-			data_type=DataType.Boolean,
-			default_value=False,
-			rules=[Boolean()]
-		)
-
-	DefinitionApi.register_definition(
-			data_type=DataType.Object,
-			data_format=Schemas.Schema(TestModel)
-		)
-
-	DefinitionApi.register_definition(
-			data_type=DataType.Array,
-			data_format='TestModel'
-		)
+	root = json.loads(json_str)
+	DefinitionApi.from_json_dict(root)
 
 
 def test__simple_array__validation():
