@@ -59,6 +59,12 @@ def register():
 			"data_type": "Object",
 			"description": "Demo model.",
 			"versions": {
+				"v0": {
+					"conversion": {
+						"config": {},
+						"type": "test.test_versions_basic_classes.TestModelVerConv_v0"
+					}
+				},
 				"v1": {
 					"conversion": {
 						"config": {},
